@@ -95,7 +95,7 @@ class Site(Site):
         # yield 'lino_xl.lib.inbox'
         # yield 'lino_xl.lib.mailbox'
         # yield 'lino_xl.lib.meetings'
-        yield 'lino_xl.lib.github'
+        # yield 'lino_xl.lib.github'
         # yield 'lino.modlib.social_auth'
         yield 'lino_xl.lib.userstats'
         yield 'lino_noi.lib.groups'
