@@ -206,7 +206,7 @@ class Ticket(Ticket, Assignable, Summarized, Hierarchical, ElasticSearchable):
     #     # self.user_changed(ar)
     #     super(Ticket, self).after_ui_create(ar)
 
-    show_commits = dd.ShowSlaveTable('github.CommitsByTicket')
+    # show_commits = dd.ShowSlaveTable('github.CommitsByTicket')
     show_changes = dd.ShowSlaveTable('changes.ChangesByMaster')
     # show_wishes = dd.ShowSlaveTable('deploy.DeploymentsByTicket')
     # show_stars = dd.ShowSlaveTable('stars.AllStarsByController')
@@ -456,9 +456,6 @@ AllSites.column_names = "ref name company group remark workflow_buttons id *"
 # """
 
 
-# Not needed, have it be inffered by mobile_columns or tablet_columns if both None, use normal grid.
-#AllTickets.display_mode_main = "responsive_grid"
-
 class TicketsByParent(Tickets):
     required_roles = dd.login_required(Reporter)
     # label = _("Known problems")
