@@ -58,7 +58,7 @@ class UserDetail(UserDetail):
     general3 = """
     created:12 modified:12 id
     date_format time_zone
-    github_username
+    #github_username
     """
 
     # cal_left = """
